powered by
Read a distance matrix from a file or data frame.
read.dist(data, el1.column = 1, el2.column = 2, dist.columns = 3)
a filename, data frame or matrix
the column name or id specifying the first element
the column name or id specifying the second element
the column name(s) or id(s) specifying the distance(s) between the two corresponding elements
a distance matrix (or list of distance matrixes when there is more than one dist.columns) of type matrix
dist.columns
matrix
# NOT RUN { read.dist(cbind(c(1,1,1,2,2,3), c(2,3,4,3,4,4), 1:6, 6:1), dist.columns=c(3,4)) # }
Run the code above in your browser using DataLab