powered by
Calculate the bag-of-characters similarity between strings.
orderinsensitivedists(strings = NULL, split = NULL, segmentcounts = segment.counts(strings, split))
a vector or list of strings
boundary sequency at which to segment the strings (default splits the string into all its constituent characters)
if custom segmentation is required, the pre-segmented strings can be passed as this argument (which is a list of lists)
a distance matrix
dist
# NOT RUN { orderinsensitivedists(c("xxxx", "asdf", "asd", "dsa")) # }
Run the code above in your browser using DataLab